Further speedup to CSR back-substitution using dof_simplenum.

PiperOrigin-RevId: 711440268
Change-Id: I81cd9a6a8b8ec78d08cfbc34f60a9216ea753833
This commit is contained in:
Yuval Tassa
2025-01-02 09:03:54 -08:00
committed by Copybara-Service
parent 69c9ac074a
commit 4510c6d290
5 changed files with 85 additions and 15 deletions
+1 -1
View File
@@ -44,7 +44,7 @@ mujoco_test(
)
mujoco_test(
engine_core_smooth_benchmark_test
solveLD_benchmark_test
MAIN_TARGET benchmark::benchmark_main
ADDITIONAL_LINK_LIBRARIES benchmark::benchmark absl::core_headers
)
@@ -64,7 +64,8 @@ static void BM_solveLD(benchmark::State& state, bool featherstone, bool coil) {
} else {
mju_copy(res, vec, m->nv);
mj_solveLDs(res, LDs, d->qLDiagInv, m->nv,
d->C_rownnz, d->C_rowadr, d->C_diag, d->C_colind);
d->C_rownnz, d->C_rowadr, d->C_diag, m->dof_simplenum,
d->C_colind);
}
}
}